'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _rollupPluginBabelHelpers = require('../../_virtual/_rollupPluginBabelHelpers.js');
var React = require('react');
var RequestLocale = require('../../server/RequestLocale.js');
var utils = require('../shared/utils.js');
var BaseLink = require('./BaseLink.js');
var baseRedirect = require('./baseRedirect.js');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var React__default = /*#__PURE__*/_interopDefault(React);

function createLocalizedPathnamesNavigation(_ref) {
  let {
    locales,
    pathnames
  } = _ref;
  function Link(_ref2) {
    let {
      href,
      locale,
      ...rest
    } = _ref2;
    const defaultLocale = RequestLocale.getRequestLocale();
    const finalLocale = locale || defaultLocale;
    return /*#__PURE__*/React__default.default.createElement(BaseLink.default, _rollupPluginBabelHelpers.extends({
      href: utils.compileLocalizedPathname({
        locale: finalLocale,
        // @ts-expect-error -- This is ok
        pathname: href,
        // @ts-expect-error -- This is ok
        params: typeof href === 'object' ? href.params : undefined,
        pathnames
      }),
      locale: locale
    }, rest));
  }
  function redirect(href) {
    const locale = RequestLocale.getRequestLocale();
    const resolvedHref = getPathname({
      href,
      locale
    });
    for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }
    return baseRedirect.default(resolvedHref, ...args);
  }
  function getPathname(_ref3) {
    let {
      href,
      locale
    } = _ref3;
    return utils.compileLocalizedPathname({
      ...utils.normalizeNameOrNameWithParams(href),
      locale,
      pathnames
    });
  }
  function notSupported(message) {
    return () => {
      throw new Error("`".concat(message, "` is not supported in Server Components. You can use this hook if you convert the component to a Client Component."));
    };
  }
  return {
    Link,
    redirect,
    getPathname,
    usePathname: notSupported('usePathname'),
    useRouter: notSupported('useRouter')
  };
}

exports.default = createLocalizedPathnamesNavigation;
